@@ -115,18 +115,11 @@ describe 'ironic::drivers::pxe' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :concat_basedir         => '/var/lib/puppet/concat',
-          :fqdn                   => 'some.host.tld',
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       let :platform_params do
-        if facts[:operatingsystem] == 'Ubuntu' and facts[:operatingsystemmajrelease] <= '20.04'
-          { :uefi_ipxe_bootfile_name => 'ipxe.efi' }
-        else
-          { :uefi_ipxe_bootfile_name => 'snponly.efi' }
-        end
+        { :uefi_ipxe_bootfile_name => 'snponly.efi' }
       end
 
       it_behaves_like 'ironic pxe driver'
