@@ -91,7 +91,7 @@ describe 'ironic::drivers::redfish' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :sushy_package_name => 'python3-sushy' }
         when 'RedHat'
